@@ -429,17 +429,17 @@ bool FloppyData::setInitialDevice(const QString& dev)
     QDBusInterface mediamanager( QStringLiteral( "org.kde.kded" ), QStringLiteral( "/modules/mediamanager" ), QStringLiteral( "org.kde.MediaManager" ) );
     QDBusReply<QStringList> reply = mediamanager.call( QStringLiteral( "properties" ), name );
     if (!reply.isValid()) {
-      qCritical() << "Invalid reply from mediamanager" << endl;
+        qCritical() << "Invalid reply from mediamanager";
     } else {
-      QStringList properties = reply;
-      newDevice = properties[5];
+      const QStringList properties = reply;
+      newDevice = properties.at(5);
     }
   }
 
   int drive = -1;
   if ( newDevice.startsWith(QLatin1String( "/dev/fd0" )) )
     drive = 0;
-  if ( newDevice.startsWith(QLatin1String( "/dev/fd1" )))
+  else if ( newDevice.startsWith(QLatin1String( "/dev/fd1" )))
     drive = 1;
 
   // ### TODO user given devices
